<?php
/**
 * app/plugins/dnd/controllers/admin/items.php
 *
 * This is the items admin controller.
 *
 * @package TTE Dungeons & Dragons
 * @version 3.0
 * @author  Joey Kimsey <Joey@tabletopelite.com>
 * @link    https://TableTopElite.com
 */
namespace TheTempusProject\Controllers\Admin;

use TheTempusProject\Houdini\Classes\Issues;
use TheTempusProject\Houdini\Classes\Views;
use TheTempusProject\Houdini\Classes\Components;
use TheTempusProject\Bedrock\Functions\Input;
use TheTempusProject\Bedrock\Functions\Check;
use TheTempusProject\Classes\Forms;
use TheTempusProject\Classes\AdminController;
use TheTempusProject\Models\Items as ItemsModel;
use TheTempusProject\Houdini\Classes\Forms as HoudiniForms;

class Items extends AdminController {
    protected static $items;

    public function __construct() {
        parent::__construct();
        self::$title = 'Admin - D&D Items';
        self::$items = new ItemsModel;
    }

    public function index( $data = null ) {
        Views::view( 'dnd.admin.items.list', self::$items->list() );
    }

    public function view( $id = null ) {
        $data = self::$items->findById( $id );
        if ( $data == false ) {
            Issues::add( 'error', 'Item not found.' );
            return $this->index();
        }
        Views::view( 'dnd.admin.items.view', $data );
    }

    public function create( $data = null ) {
        Components::set( 'privacyDropdown', Views::simpleView('dnd.forms.privacyDropdown') );
        Components::set( 'versionDropdown', Views::simpleView('dnd.forms.versionDropdown') );
        $sourcebookSelect = HoudiniForms::getFormFieldHtml( 'sourcebookID', 'SourceBook', 'select', 'none', self::$sourcebooks->simpleList() );
        Components::set( 'sourcebookSelect', $sourcebookSelect );
        if ( !Input::exists( 'submit' ) ) {
            Views::view( 'dnd.admin.items.create' );
        }
        if ( !Forms::check( 'createItem' ) ) {
            Issues::add( 'error', [ 'There was an error with your request.' => Check::userErrors() ] );
            return Views::view( 'dnd.admin.items.create' );
        }
        if ( self::$items->create( Input::post( 'name' )) ) {
            Issues::add( 'success', 'Item created' );
            return $this->index();
        } else {
            Issues::add( 'error', 'There was an error creating your item.' );
            return Views::view( 'dnd.admin.items.create' );
        }
    }

    public function edit( $id = null ) {
        $data = self::$items->findById( $id );
        if ( false == $data ) {
            return $this->index();
        }
        Components::set( 'privacyDropdown', Views::simpleView('dnd.forms.privacyDropdown', $data) );
        Components::set( 'versionDropdown', Views::simpleView('dnd.forms.versionDropdown', $data) );
        $sourcebookSelect = HoudiniForms::getFormFieldHtml( 'sourcebookID', 'SourceBook', 'select', $data->sourcebookID, self::$sourcebooks->simpleList() );
        Components::set( 'sourcebookSelect', $sourcebookSelect );
        if ( !Input::exists( 'submit' ) ) {
            return Views::view( 'dnd.admin.items.edit', $data );
        }
        if ( !Forms::check( 'editItem' ) ) {
            Issues::add( 'error', [ 'There was an error with your request.' => Check::userErrors() ] );
            return Views::view( 'dnd.admin.items.edit', $data );
        }
        if ( self::$items->update( $id, Input::post( 'title' ), Input::post( 'suggestion' ), Input::post( 'approved' ) ) ) {
            Issues::add( 'success', 'Item updated' );
        } else {
            return Views::view( 'dnd.admin.items.edit', $data );
        }
    }

    public function delete( $data = null ) {
        if ( Input::exists( 'submit' ) ) {
            $data = Input::post( 'It_' );
        }
        if ( !self::$items->delete( $data ) ) {
            Issues::add( 'error', 'There was an error with your request.' );
        } else {
            Issues::add( 'success', 'Item has been deleted' );
        }
        $this->index();
    }
}
