<?php
/**
 * app/plugins/dnd/controllers/admin/races.php
 *
 * This is the races admin controller.
 *
 * @package TTE Dungeons & Dragons
 * @version 3.0
 * @author  Joey Kimsey <Joey@tabletopelite.com>
 * @link    https://TableTopElite.com
 */
namespace TheTempusProject\Controllers\Admin;

use TheTempusProject\Houdini\Classes\Issues;
use TheTempusProject\Houdini\Classes\Views;
use TheTempusProject\Houdini\Classes\Components;
use TheTempusProject\Bedrock\Functions\Input;
use TheTempusProject\Bedrock\Functions\Check;
use TheTempusProject\Classes\Forms;
use TheTempusProject\Classes\AdminController;
use TheTempusProject\Models\Races as RacesModel;
use TheTempusProject\Houdini\Classes\Forms as HoudiniForms;

class Races extends AdminController {
    protected static $races;

    public function __construct() {
        parent::__construct();
        self::$title = 'Admin - D&D Races';
        self::$races = new RacesModel;
    }

    public function index( $data = null ) {
        Views::view( 'dnd.admin.races.list', self::$races->list() );
    }

    public function view( $id = null ) {
        $data = self::$races->findById( $id );
        if ( $data == false ) {
            Issues::add( 'error', 'Race not found.' );
            return $this->index();
        }
        Views::view( 'dnd.admin.races.view', $data );
    }

    public function create( $data = null ) {
        Components::set( 'privacyDropdown', Views::simpleView('dnd.forms.privacyDropdown') );
        Components::set( 'versionDropdown', Views::simpleView('dnd.forms.versionDropdown') );
        $sourcebookSelect = HoudiniForms::getFormFieldHtml( 'sourcebookID', 'SourceBook', 'select', 'none', self::$sourcebooks->simpleList() );
        Components::set( 'sourcebookSelect', $sourcebookSelect );
        if ( !Input::exists( 'submit' ) ) {
            Views::view( 'dnd.admin.races.create' );
        }
        if ( !Forms::check( 'createRace' ) ) {
            Issues::add( 'error', [ 'There was an error with your request.' => Check::userErrors() ] );
            return Views::view( 'dnd.admin.races.create' );
        }
        if ( self::$races->create( Input::post( 'name' )) ) {
            Issues::add( 'success', 'Race created' );
            return $this->index();
        } else {
            Issues::add( 'error', 'There was an error creating your race.' );
            return Views::view( 'dnd.admin.races.create' );
        }
    }

    public function edit( $id = null ) {
        $data = self::$races->findById( $id );
        if ( false == $data ) {
            return $this->index();
        }
        Components::set( 'privacyDropdown', Views::simpleView('dnd.forms.privacyDropdown', $data) );
        Components::set( 'versionDropdown', Views::simpleView('dnd.forms.versionDropdown', $data) );
        $sourcebookSelect = HoudiniForms::getFormFieldHtml( 'sourcebookID', 'SourceBook', 'select', $data->sourcebookID, self::$sourcebooks->simpleList() );
        Components::set( 'sourcebookSelect', $sourcebookSelect );
        if ( !Input::exists( 'submit' ) ) {
            return Views::view( 'dnd.admin.races.edit', $data );
        }
        if ( !Forms::check( 'editRace' ) ) {
            Issues::add( 'error', [ 'There was an error with your request.' => Check::userErrors() ] );
            return Views::view( 'dnd.admin.races.edit', $data );
        }
        if ( self::$races->update( $id, Input::post( 'title' ), Input::post( 'suggestion' ), Input::post( 'approved' ) ) ) {
            Issues::add( 'success', 'Race updated' );
        } else {
            return Views::view( 'dnd.admin.races.edit', $data );
        }
    }

    public function delete( $data = null ) {
        if ( Input::exists( 'submit' ) ) {
            $data = Input::post( 'RA_' );
        }
        if ( !self::$races->delete( $data ) ) {
            Issues::add( 'error', 'There was an error with your request.' );
        } else {
            Issues::add( 'success', 'Race has been deleted' );
        }
        $this->index();
    }
}
